==> julia-git-quantumsymbolics-src-0.2.7-1-any.pkg.tar.zst: usr/share/julia/arch-site/QuantumSymbolics/README.md <==
# QuantumSymbolics

Computer algebra tools for symbolic manipulations in quantum mechanics and quantum information.

<table>
    <tr>
        <td>Documentation</td>
        <td>
            <a href="https://quantumsavory.github.io/QuantumSymbolics.jl/stable"><img src="https://img.shields.io/badge/docs-stable-blue.svg" alt="Documentation of latest stable version"></a>
            <a href="https://quantumsavory.github.io/QuantumSymbolics.jl/dev"><img src="https://img.shields.io/badge/docs-dev-blue.svg" alt="Documentation of dev version"></a>
        </td>
    </tr><tr></tr>
    <tr>
        <td>Continuous integration</td>
        <td>
            <a href="https://github.com/QuantumSavory/QuantumSymbolics.jl/actions?query=workflow%3ACI+branch%3Amain"><img src="https://github.com/QuantumSavory/QuantumSymbolics.jl/actions/workflows/ci.yml/badge.svg" alt="GitHub Workflow Status"></a>
            <a href="https://buildkite.com/quantumsavory/quantumsymbolics"><img src="https://badge.buildkite.com/f5d8fe7ebb50cf445cec53e9fc47052e4613af3682c2668371.svg?branch=main" alt="Buildkite Workflow Status"></a>
        </td>
    </tr><tr></tr>
    <tr>
        <td>Code coverage</td>
        <td>
            <a href="https://codecov.io/gh/QuantumSavory/QuantumSymbolics.jl"><img src="https://img.shields.io/codecov/c/gh/QuantumSavory/QuantumSymbolics.jl?label=codecov" alt="Test coverage from codecov"></a>
        </td>
    </tr><tr></tr>
    <tr>
        <td>Static analysis with</td>
        <td>
            <a href="https://github.com/aviatesk/JET.jl"><img src="https://img.shields.io/badge/JET.jl-%E2%9C%88%EF%B8%8F-9cf" alt="JET static analysis"></a>
            <a href="https://github.com/JuliaTesting/Aqua.jl"><img src="https://raw.githubusercontent.com/JuliaTesting/Aqua.jl/master/badge.svg" alt="Aqua QA"></a>
        </td>
    </tr>
</table>

==> julia-git-quantumsymbolics-src-0.4.10-1-any.pkg.tar.zst: usr/share/julia/arch-site/QuantumSymbolics/README.md <==
# QuantumSymbolics

Computer algebra tools for symbolic manipulations in quantum mechanics and quantum information.

<table>
    <tr>
        <td>Documentation</td>
        <td>
            <a href="https://quantumsavory.github.io/QuantumSymbolics.jl/stable"><img src="https://img.shields.io/badge/docs-stable-blue.svg" alt="Documentation of latest stable version"></a>
            <a href="https://quantumsavory.github.io/QuantumSymbolics.jl/dev"><img src="https://img.shields.io/badge/docs-dev-blue.svg" alt="Documentation of dev version"></a>
        </td>
    </tr><tr></tr>
    <tr>
        <td>Continuous integration</td>
        <td>
            <a href="https://github.com/QuantumSavory/QuantumSymbolics.jl/actions?query=workflow%3ACI+branch%3Amain"><img src="https://github.com/QuantumSavory/QuantumSymbolics.jl/actions/workflows/ci.yml/badge.svg" alt="GitHub Workflow Status"></a>
            <a href="https://buildkite.com/quantumsavory/quantumsymbolics"><img src="https://badge.buildkite.com/f5d8fe7ebb50cf445cec53e9fc47052e4613af3682c2668371.svg?branch=main" alt="Buildkite Workflow Status"></a>
        </td>
    </tr><tr></tr>
    <tr>
        <td>Code coverage</td>
        <td>
            <a href="https://codecov.io/gh/QuantumSavory/QuantumSymbolics.jl"><img src="https://img.shields.io/codecov/c/gh/QuantumSavory/QuantumSymbolics.jl?label=codecov" alt="Test coverage from codecov"></a>
        </td>
    </tr><tr></tr>
    <tr>
        <td>Static analysis with</td>
        <td>
            <a href="https://github.com/aviatesk/JET.jl"><img src="https://img.shields.io/badge/%F0%9F%9B%A9%EF%B8%8F_tested_with-JET.jl-233f9a" alt="JET static analysis"></a>
            <a href="https://github.com/JuliaTesting/Aqua.jl"><img src="https://raw.githubusercontent.com/JuliaTesting/Aqua.jl/master/badge.svg" alt="Aqua QA"></a>
        </td>
    </tr>
</table>
